update README
[paraslash.git] / server.h
index b01c3f6a926da6122f0c2931ac200e06d7006436..fcda7a3ace835d65c0e960640291396e62f628ea 100644 (file)
--- a/server.h
+++ b/server.h
@@ -21,7 +21,7 @@
 #include "para.h"
 
 
/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 
 /**
@@ -139,13 +139,13 @@ struct misc_meta_data{
        unsigned int active_connections;
 /** the process id of para_server */
        pid_t server_pid;
-/** a string that gets filled in by the current database tool */
-       char dbinfo[MMD_INFO_SIZE];
-/** the number if the current database tool */
-       int dbt_num;
-/** commands set this to non-zero to request a database tool change */
-       int dbt_change;
-/* used by the sender command */
+/** a string that gets filled in by the current audio file selector */
+       char selector_info[MMD_INFO_SIZE];
+/** the number if the current audio file selector */
+       int selector_num;
+/** commands set this to non-zero to change the current selector */
+       int selector_change;
+/** used by the sender command */
        struct sender_command_data sender_cmd_data;
 };
@@ -21,7 +21,7 @@
 
 
-/** size of the dbinfo and audio_file info strings of struct misc_meta_data */
+/** size of the selector_info and audio_file info strings of struct misc_meta_data */
 #define MMD_INFO_SIZE 16384
 